@@ -1,22 +1,18 @@
 ( cd usr/bin ; rm -rf parec )
 ( cd usr/bin ; ln -sf pacat parec )
-( cd usr/lib ; rm -rf libpulse-browse.so )
-( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so )
-( cd usr/lib ; rm -rf libpulse.so )
-( cd usr/lib ; ln -sf libpulse.so.0.7.0 libpulse.so )
-( cd usr/lib ; rm -rf libpulse-mainloop-glib.so )
-( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so )
 ( cd usr/lib ; rm -rf libpulse.so.0 )
-( cd usr/lib ; ln -sf libpulse.so.0.7.0 libpulse.so.0 )
-( cd usr/lib ; rm -rf libpulse-mainloop-glib.so.0 )
-( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so.0 )
+( cd usr/lib ; ln -sf libpulse.so.0.8.0 libpulse.so.0 )
+( cd usr/lib ; rm -rf libpulse.so )
+( cd usr/lib ; ln -sf libpulse.so.0.8.0 libpulse.so )
 ( cd usr/lib ; rm -rf libpulse-simple.so.0 )
 ( cd usr/lib ; ln -sf libpulse-simple.so.0.0.2 libpulse-simple.so.0 )
-( cd usr/lib ; rm -rf libpulsecore.so.8 )
-( cd usr/lib ; ln -sf libpulsecore.so.8.0.0 libpulsecore.so.8 )
-( cd usr/lib ; rm -rf libpulse-browse.so.0 )
-( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so.0 )
-( cd usr/lib ; rm -rf libpulsecore.so )
-( cd usr/lib ; ln -sf libpulsecore.so.8.0.0 libpulsecore.so )
 ( cd usr/lib ; rm -rf libpulse-simple.so )
 ( cd usr/lib ; ln -sf libpulse-simple.so.0.0.2 libpulse-simple.so )
+( cd usr/lib ; rm -rf libpulse-browse.so.0 )
+( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so.0 )
+( cd usr/lib ; rm -rf libpulse-browse.so )
+( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so )
+( cd usr/lib ; rm -rf libpulse-mainloop-glib.so.0 )
+( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so.0 )
+( cd usr/lib ; rm -rf libpulse-mainloop-glib.so )
+( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so )
